<p align="center">
  <img width="491" alt="basata" src="https://github.com/sg-tarek/BASATA/blob/main/logo.png">
</p>



Installing
============

    pip install basata

Usage
=====

    from basata.basata import *

Upgrade
=====

    pip install --upgrade basata

or

    pip install --upgrade basata==<VERSION_NUMBER>